function [tsave,ysave] = RKF45(f,y0,t0,T,h0,atol,rtol)

% function RKF45
%
% Zweck: integriere die gewoehnliche Diff.-Gleichung erster Ordnung
%
%          dy/dt = f(t,y(t))
%
%        mit einem (zu?) einfachen Runge-Kutta-Fehlberg Verfahren 
%        basierend auf eingebetteten Runge-Kutta Verfahren der 
%        Ordnung 4 und 5
%
% Parameters: f        ... rechte Seite f(t,y(t)) der gew. Diff.-Gl.
%             t0,T     ... Start- und End-Zeit
%             y0       ... Anfagswert
%             h0       ... Anfangs-Schrittweite
%             atol     ... Absolute Toleranz
%             vararing ... Für Infos über varargin, siehe Matlab
%                          Dokumentation
%
% Returns: t ... Zeiten
%          y ... approx. Loesung zu Zeiten t
%
% Notes: keine
%

% Initialisiere Zeit- und Loesungs-Vektor
y = y0;
t = t0;
h = h0;

% Parameter
p       = 4;
hmin    = 10*eps; % kleinste zugelassene Schrittweite
fac     = 0.9;    % Sicherheits-Faktor
facmin  = 0.5;    % kleinste zugelassene Schrittweiten-Verkleinerung
facmax  = 1.5;    % groesste zugelassene Schrittweiten-Vergroesserung
epsilon = atol + norm(y0)*rtol; % Initialisiere Fehlerschaetzer
